@@ -903,7 +903,7 @@ class UWC_Page {
   }
 
   function include_external() {
-    uwc_external_include($this->conf, $this->get_path(), $this->get_lang());
+    uwc_external_include($this);
   }
 
   function set_http_code($http_code) {
